@@ -1,6 +1,14 @@
 __all__ = ['CurrencyRGame', 'Factory', 'GuessGame', 'mainGame',
            'MemoryGame', 'utils', 'wog_abs']
 
+from utils import get_user_name, welcome, load_game, number_to_game ,is_digit
+from Factory import Factory
+from wog_abs import WoG
+from MemoryGame import MemoryGame
+from GuessGame import GuessGame
+from CurrencyRGame import CurrencyRGame
+
+
 #from .__main__ import main
 #import mainGame
 #from setuptools import setup, find_packages
